@@ -1,3 +1,5 @@
+#![allow(clippy::nonstandard_macro_braces)]
+
 #[macro_use]
 extern crate diesel;
 
@@ -13,3 +15,8 @@ pub mod worker_pool;
 pub use executor::*;
 pub use postgres::*;
 pub use worker_pool::*;
+
+#[doc(hidden)]
+pub use serde::{Deserialize, Serialize};
+#[doc(hidden)]
+pub use typetag;
